%% GOLDEN SECTION SEARCH METHOD %%
%% Developed by Dr. Rajib Kuamr Bhattacharjya %%
%% Department of Civil Engineering, IIT Guwahati %%
%% This method is used to obtain the minima of a minimization function
%% 'a' and 'b' are the upper bound and lower bound of search space 
%% 'e' is the permissible error
%% funcName is the name of the function 
%% w1 and w2 are the lower and upper bound of the search space after end of
%% the iteration 
%% k is the number of iteration required to obtain the optima
%% An example function 'func' has been provided
%% For obtaining the minima of the function just excecute the goldenSection
%% function using "[w1 w3 k]=goldenSection(0,4,0.001,'func')" 
%% Where a=0,b=4, e=0.001 and funcName='func
function [w1,w2,k]=goldenSection(a,b,e,funcName)
L = b-a;
w1=a+0.618*L;
w2=b-0.618*L;
fw1=feval(funcName,w1);
fw2=feval(funcName,w2);
k=2;
while (L>e)
    if(fw1<fw2)
        a=w2;w2=w1;fw2=fw1;
        L=b-a;
        w1=a+0.618*L;
        fw1=feval(funcName,w1);
        k=k+1;
    else
        b=w1;w1=w2;fw1=fw2;
        L=b-a;
        w2=b-+0.618*L;
        fw2=feval(funcName,w2);
        k=k+1;
    end
end